@@ -1,8 +1,8 @@
 run.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN = 2000000)
 {
   res <- call.eqs(EQSpgm = EQSpgm, EQSmodel = EQSmodel, serial = serial, Rmatrix = Rmatrix, datname = datname, LEN = LEN)
-  
-  if (res == -1) warning("EQS estimation not successful!")
+    
+  if (!res) warning("EQS estimation not successful!")
   
   filedir.split <- strsplit(EQSmodel, "/")[[1]]
   n <- length(filedir.split)
@@ -10,6 +10,6 @@ run.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN =
   etsfile <- paste(etsname, ".ets",sep = "" )
   
   reslist <- read.eqs(etsfile)
-  return(reslist)
+  return(c(list(success = res),reslist))
 }
 
